==> haskell-wai-extra-3.0.14.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.14.1
id: wai-extra-3.0.14.1-5f3982898a5be41036c34bae0277136d
key: waiex_8hPy1tUPe8O82jHtPph3ET
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.Local Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.StripHeaders
    Network.Wai.Middleware.Vhost Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Routed Network.Wai.Parse Network.Wai.Request
    Network.Wai.UrlMap Network.Wai.Test Network.Wai.EventSource
    Network.Wai.EventSource.EventStream
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.14.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.14.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-extra-3.0.14.1
hs-libraries: HSwai-extra-3.0.14.1-8hPy1tUPe8O82jHtPph3ET
depends:
    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
    stringsearch-0.3.6.6-bd5f901f10569d353c3dabbb227e877c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.14.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.14.1
id: wai-extra-3.0.14.1-66e8055b51d984feb43fefdbcd17f927
key: waiex_ETHp0AagaZY8Q4kpUIOhpj
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.Local Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.StripHeaders
    Network.Wai.Middleware.Vhost Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Routed Network.Wai.Parse Network.Wai.Request
    Network.Wai.UrlMap Network.Wai.Test Network.Wai.EventSource
    Network.Wai.EventSource.EventStream
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.14.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.14.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-extra-3.0.14.1
hs-libraries: HSwai-extra-3.0.14.1-ETHp0AagaZY8Q4kpUIOhpj
depends:
    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
    stringsearch-0.3.6.6-bd5f901f10569d353c3dabbb227e877c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
